pub struct IncomingConnection {
pub metadata: Metadata,
/* private fields */
}Expand description
An incoming virtual connection request.
Received via the IncomingConnections receiver returned from accept_framed().
Call accept() to accept the connection and get a handle,
or reject() to refuse it.
Fields
metadata: MetadataMetadata from the Connect message.
Implementations
Sourceimpl IncomingConnection
impl IncomingConnection
Sourcepub async fn accept(
self,
metadata: Metadata,
dispatcher: Option<Box<dyn ServiceDispatcher>>,
) -> Result<ConnectionHandle, TransportError>
pub async fn accept( self, metadata: Metadata, dispatcher: Option<Box<dyn ServiceDispatcher>>, ) -> Result<ConnectionHandle, TransportError>
Accept this connection and receive a handle for it.
The metadata will be sent in the Accept message.
The dispatcher will handle incoming requests on this virtual connection.
If None, the parent link’s dispatcher will be used (and only calls can be made,
not received).
Note: The returned ConnectionHandle cannot itself accept nested connections.
r[impl core.conn.only-root-accepts]