IncomingConnections

Type Alias IncomingConnections 

pub type IncomingConnections = Receiver<IncomingConnection>;
Receiver for incoming virtual connection requests.

Returned from accept_framed(). Each item is an IncomingConnection that can be accepted or rejected.

If this receiver is dropped, all pending and future Connect requests will be automatically rejected with “not listening”.

Aliased Type

pub struct IncomingConnections { /* private fields */ }